# eric7.Preferences.ConfigurationPages.NetworkPage

Module implementing the Network configuration page.

### Global Attributes

None

### Classes

NetworkPage | Class implementing the Network configuration page.

### Functions

create | Module function to create the configuration page.

## NetworkPage

Class implementing the Network configuration page.

### Derived from

ConfigurationPageBase, Ui_NetworkPage

### Class Attributes

None

### Class Methods

None

### Methods

NetworkPage | Constructor
save | Public slot to save the Networj configuration.
setMode | Public method to perform mode dependent setups.

### Static Methods

None

#### NetworkPage (Constructor)

NetworkPage(configDialog)

Constructor

configDialog (ConfigurationDialog)
  reference to the configuration dialog

#### NetworkPage.save

save()

Public slot to save the Networj configuration.

#### NetworkPage.setMode

setMode(displayMode)

Public method to perform mode dependent setups.

displayMode (ConfigurationMode)
  mode of the configuration dialog

Up

## create

create(dlg)

Module function to create the configuration page.

dlg (ConfigurationDialog)
  reference to the configuration dialog

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up